@@ -27,6 +27,7 @@
 # - Eli Chadwick <eli.chadwick@stfc.ac.uk>, 2020
 # - Radu Carpa <radu.carpa@cern.ch>, 2021
 # - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2021
+# - Joel Dierkes <joel.dierkes@cern.ch>, 2021
 
 from json import dumps, loads
 
@@ -44,9 +45,6 @@ class RuleClient(BaseClient):
 
     RULE_BASEURL = 'rules'
 
-    def __init__(self, rucio_host=None, auth_host=None, account=None, ca_cert=None, auth_type=None, creds=None, timeout=600, dq2_wrapper=False, vo=None):
-        super(RuleClient, self).__init__(rucio_host, auth_host, account, ca_cert, auth_type, creds, timeout, dq2_wrapper, vo=vo)
-
     def add_replication_rule(self, dids, copies, rse_expression, weight=None, lifetime=None, grouping='DATASET', account=None,
                              locked=False, source_replica_expression=None, activity=None, notify='N', purge_replicas=False,
                              ignore_availability=False, comment=None, ask_approval=False, asynchronous=False, delay_injection=None,
@@ -82,7 +80,7 @@ class RuleClient(BaseClient):
                       'activity': activity, 'notify': notify, 'purge_replicas': purge_replicas,
                       'ignore_availability': ignore_availability, 'comment': comment, 'ask_approval': ask_approval,
                       'asynchronous': asynchronous, 'delay_injection': delay_injection, 'priority': priority, 'meta': meta})
-        r = self._send_request(url, type='POST', data=data)
+        r = self._send_request(url, type_='POST', data=data)
         if r.status_code == codes.created:
             return loads(r.text)
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -102,7 +100,7 @@ class RuleClient(BaseClient):
 
         data = dumps({'purge_replicas': purge_replicas})
 
-        r = self._send_request(url, type='DEL', data=data)
+        r = self._send_request(url, type_='DEL', data=data)
 
         if r.status_code == codes.ok:
             return True
@@ -120,7 +118,7 @@ class RuleClient(BaseClient):
         path = self.RULE_BASEURL + '/' + rule_id
         url = build_url(choice(self.list_hosts), path=path)
         data = dumps({'estimate_ttc': estimate_ttc})
-        r = self._send_request(url, type='GET', data=data)
+        r = self._send_request(url, type_='GET', data=data)
         if r.status_code == codes.ok:
             return next(self._load_json_data(r))
         else:
@@ -136,7 +134,7 @@ class RuleClient(BaseClient):
         path = self.RULE_BASEURL + '/' + rule_id
         url = build_url(choice(self.list_hosts), path=path)
         data = dumps({'options': options})
-        r = self._send_request(url, type='PUT', data=data)
+        r = self._send_request(url, type_='PUT', data=data)
         if r.status_code == codes.ok:
             return True
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -153,25 +151,32 @@ class RuleClient(BaseClient):
         path = self.RULE_BASEURL + '/' + rule_id + '/reduce'
         url = build_url(choice(self.list_hosts), path=path)
         data = dumps({'copies': copies, 'exclude_expression': exclude_expression})
-        r = self._send_request(url, type='POST', data=data)
+        r = self._send_request(url, type_='POST', data=data)
         if r.status_code == codes.ok:
             return loads(r.text)
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
         raise exc_cls(exc_msg)
 
-    def move_replication_rule(self, rule_id, rse_expression):
+    def move_replication_rule(self, rule_id, rse_expression, activity, source_replica_expression):
         """
         Move a replication rule to another RSE and, once done, delete the original one.
 
-        :param rule_id:             Rule to be moved.
-        :param rse_expression:      RSE expression of the new rule.
-        :raises:                    RuleNotFound, RuleReplaceFailed
+        :param rule_id:                    Rule to be moved.
+        :param rse_expression:             RSE expression of the new rule.
+        :param activity:                   Activity of the new rule.
+        :param source_replica_expression:  Source-Replica-Expression of the new rule.
+        :raises:                           RuleNotFound, RuleReplaceFailed
         """
 
         path = self.RULE_BASEURL + '/' + rule_id + '/move'
         url = build_url(choice(self.list_hosts), path=path)
-        data = dumps({'rule_id': rule_id, 'rse_expression': rse_expression})
-        r = self._send_request(url, type='POST', data=data)
+        data = dumps({
+            'rule_id': rule_id,
+            'rse_expression': rse_expression,
+            'activity': activity,
+            'source_replica_expression': source_replica_expression
+        })
+        r = self._send_request(url, type_='POST', data=data)
         if r.status_code == codes.created:
             return loads(r.text)
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -186,7 +191,7 @@ class RuleClient(BaseClient):
         path = self.RULE_BASEURL + '/' + rule_id
         url = build_url(choice(self.list_hosts), path=path)
         data = dumps({'options': {'approve': True}})
-        r = self._send_request(url, type='PUT', data=data)
+        r = self._send_request(url, type_='PUT', data=data)
         if r.status_code == codes.ok:
             return True
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -201,7 +206,7 @@ class RuleClient(BaseClient):
         path = self.RULE_BASEURL + '/' + rule_id
         url = build_url(choice(self.list_hosts), path=path)
         data = dumps({'options': {'approve': False}})
-        r = self._send_request(url, type='PUT', data=data)
+        r = self._send_request(url, type_='PUT', data=data)
         if r.status_code == codes.ok:
             return True
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -216,7 +221,7 @@ class RuleClient(BaseClient):
         """
         path = '/'.join([self.RULE_BASEURL, quote_plus(scope), quote_plus(name), 'history'])
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return self._load_json_data(r)
         exc_cls, exc_msg = self._get_exception(r.headers, r.status_code)
@@ -231,7 +236,7 @@ class RuleClient(BaseClient):
         """
         path = self.RULE_BASEURL + '/' + rule_id + '/analysis'
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return next(self._load_json_data(r))
         exc_cls, exc_msg = self._get_exception(r.headers, r.status_code)
@@ -246,7 +251,7 @@ class RuleClient(BaseClient):
         """
         path = self.RULE_BASEURL + '/' + rule_id + '/locks'
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return self._load_json_data(r)
         exc_cls, exc_msg = self._get_exception(r.headers, r.status_code)
@@ -262,7 +267,7 @@ class RuleClient(BaseClient):
         filters = filters or {}
         path = self.RULE_BASEURL + '/'
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='GET', params=filters)
+        r = self._send_request(url, type_='GET', params=filters)
         if r.status_code == codes.ok:
             return self._load_json_data(r)
         else:
